.. _status:

+++++++++++++
Release Notes
+++++++++++++

*****
0.0.3
*****

Add hierachical namespace

*****
0.0.2
*****

Release using new ga4gh packages, ga4gh-common and ga4gh-schemas

*****
0.0.1
*****

Initial release
